<?php
/**
 * Descriere: datafeed in format XML pentru cauti.ro
 * Platforma: OpenCart v1.4.7
 */

set_time_limit(0);
ini_set('display_errors', 0);

// include configuration files
require_once ( 'config.php' );

/**
 * Datele de autentificare si conectare la baza de date
 * Modificati numai daca doriti sa folositi alte date de conectare decat cele din fisierul de configurare al CS-Cart
 * @var array
 */
$sqlAcces = array(
	'databaseType'	=> 'mysql',					// tipul bazei de date; sunt suportate urmatoarele tipuri: mysql si mssql
	'username'		=> DB_USERNAME,				// username-ul folosit pentru acces la server
	'password'		=> DB_PASSWORD,				// parola pentru acces la server
	'host'			=> DB_HOSTNAME,				// adresa IP sau numele serverului, urmat optional de ':' si portul
	'database'		=> DB_DATABASE				// baza de date folosita
);

/**
 * URL-ul site-ului
 */
if (!defined('HTTP_SERVER'))
{
	define('HTTP_SERVER', 'http://' . $_SERVER['HTTP_HOST'] . rtrim(dirname($_SERVER['PHP_SELF']), '/') . '/');
}

$site_url	= HTTP_SERVER;

if (!defined('HTTP_IMAGE'))
{
	define('HTTP_IMAGE', HTTP_SERVER . 'image/');
}

$image_url = HTTP_IMAGE;

/**
 * Clasa pentru export lista produse de la client cauti.ro
 */
class Export
{
	/**
	 * tipul bazei de date
	 * @var string
	 */
	private $dbType = null;
	
	/**
	 * conexiunea la DB
	 * @var mixed
	 */
	private $conexiune = null;
	
	/**
	 * Descriere: cosntructor
	 */
	function Export(&$sqlAcces)
	{
		/**
		 * Conectare la baza de date
		 */
		$this->connect($sqlAcces);
	}
	
	/**
	 * Genereaza lista de produse in format XML si afiseaza in browser dupa ce se genereaza fiecare produs.
	 * 
	 * @param string $site_url URL-ul principal al site-ului
	 * @param string $image_url URL-ul directorului cu pozele produselor
	 */
	function generateTextXMLOutput($site_url, $image_url)
	{
		// Detectez id-ul limbii default
		$q = "
				SELECT `language_id`
				FROM setting s
				INNER JOIN language l ON l.`code` = s.`value`
				WHERE s.`key` = 'config_language'
			";
		$res = $this->query($q);
		$row = $this->fetch_assoc($res);
		$lang_id = $row['language_id'];
		
		// Obtin moneda default
		$q = "SELECT `value` FROM setting WHERE `key`='config_currency'";
		$res = $this->query($q);
		$row = $this->fetch_assoc($res);
		$default_currency = trim($row['value']);

		// Obtin valoarea cursului de schimb pentru moneda default
		$q = "SELECT `value` FROM currency WHERE `code`='$default_currency'";
		$res = $this->query($q);
		$row = $this->fetch_assoc($res);
		$currency_value = $row['value'];

		// Daca moneda default nu este LEU obtin valoarea cursului de schimb pentru LEU
		if (!in_array(strtoupper($default_currency), array('RON', 'LEU', 'LEI')))
		{
			$q = "SELECT `value` FROM currency WHERE UPPER(`code`) = 'RON' OR UPPER(`code`) = 'LEU' OR UPPER(`code`) = 'LEI'";
			$res = $this->query($q);
			$row = $this->fetch_assoc($res);
			$currency_value = $row['value'];
		}
		
		// Obtin toate categoriile
		$q = "
				SELECT *
				FROM category
				LEFT JOIN category_description ON category_description.`category_id` = category.`category_id`
				WHERE category_description.`language_id` = $lang_id
			";
		$res_cat = $this->query($q);
		if ($res_cat) 
		{
			while ($field = $this->fetch_assoc($res_cat)) 
			{
				$CAT_ARR[$field['category_id']] = $field;
			}
		}
		
		// Construiesc arborele categoriilor
		$CAT_TREE = $this->make_tree($CAT_ARR);
		
		/**
		 * Stringul care contine query-ul SQL folosit la obtinerea listei de produse
		 * @var string
		 */
		$query = "
					SELECT DISTINCT 
						p.product_id as cod,
						IFNULL(m.name, '-') as numemarca,
						pc.category_id as category_id,
						pdesc.name as numeprodus,
						p.price AS pret,
						p.quantity as stoc,
						p.sku AS mpn,
						pdesc.description as descriere,
						pi.image AS imgfile,
						p.image AS poza,
						'' as garantia,
						tr.rate as taxa
					FROM product p
					LEFT JOIN manufacturer m ON p.manufacturer_id = m.manufacturer_id
					LEFT JOIN product_description pdesc ON pdesc.product_id = p.product_id
					LEFT JOIN product_to_category pc ON pc.product_id = p.product_id
					LEFT JOIN product_image pi ON pi.product_id = p.product_id
--					LEFT JOIN image img ON pi.image_id = img.image_id
					LEFT JOIN tax_rate tr ON tr.tax_class_id = p.tax_class_id
					WHERE p.status = 1
						AND pdesc.language_id = $lang_id
				";

		/**
		 * Executie query
		 */
		if (!$result = $this->query($query)) 								// daca query-ul a generat erori
			die('Eroare la rularea query-ului. Verificati sintaxa!'.mysql_error() );		// semnalam eroare si oprim scriptul
		
		/**
		 * BEGIN Sectiune generare si afisare XML
		 */
		
		/* 
		 * creeaza capul documentului si nodul radacina
		 */
		$xmlHead = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<produse xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://www.cauti.ro/produse.xsd\">\n";
		echo $xmlHead;		// afiseaza capul de document
		flush();			// forteaza afisare
		
		/**
		 * Initializari variabile
		 */
		$i			= 0;
		$produs 	= array();
		$arrProduse = array();
		
		// array cu caracterele de inlocuit
		$search 	= array('\r\n','\n','&trade;','&copy;','&reg;','™','&deg;','&icirc;','&acirc;','&#206','&#258;','&#259;','&#350;','&#351;','&#354;','&#355;','Â','â','Ă','ă','Î','î','Ş','ş','Ţ','ţ');
		// array cu caracterele cu care se inlocuiesc caracterele de mai sus
		$replace 	= array(' ',' ',' ',' ',' ',' ','grade','i','a','I','A','a','S','s','T','t','A','a','A','a','I','i','S','s','T','t');
		
		/**
		 * Parcurge toate tuplele returnate de query
		 */
		while ($row = $this->fetch_assoc($result))
		{
			/**
			 * Initializez variabilele folosite in construirea arrayului $produs.
			 */
			$cod = htmlentities(strip_tags(trim($row['cod'])));
			
			// evit transmiterea de produse duplicat
			if (isset($arrProduse[$cod])) continue;
			
			$arrProduse[$cod] = 1;
			
			// Obtin numele categoriei
			$cat_id	= trim($row['category_id']);
			if (isset($CAT_TREE[$cat_id]) && $CAT_TREE[$cat_id]['cat_string'] != "")
			{
				$nume_categorie = htmlentities(strip_tags(str_replace($search, $replace, trim($CAT_TREE[$cat_id]['cat_string']))));
			}
			else 
			{
				$nume_categorie = "undefined";
			}
			
			$nume_produs	= htmlentities(strip_tags(str_replace($search, $replace, trim($row['numeprodus']))));
			$marca 			= htmlentities(strip_tags(trim($row['numemarca'])));
			$cat_path		= isset($CAT_TREE[$cat_id]) ? '&path='.$CAT_TREE[$cat_id]['cat_string'] : '';
			$url_produs		= $site_url.'index.php?route=product/product&product_id='.urlencode($cod);
			$pret_lei		= htmlentities(strip_tags(trim($row['pret']))) * ((isset($row['taxa']))	? 1+floatval($row['taxa'])/100 : 1);
			if ($currency_value)
				$pret_lei = $pret_lei * $currency_value;
			$inStoc 		= ($row['stoc'] > 0) ? 1 : 0;
			
			$garantia 		= htmlentities(strip_tags(trim($row['garantia'])));
			$mpn			= isset($row['mpn']) ? htmlentities(strip_tags(trim($row['mpn']))) : '';
			$descriere		= htmlentities(strip_tags(str_replace($search, $replace, trim($row['descriere']))));			
			$url_poza1		= '';
			if (trim($row['imgfile']) != '')
			{
				$url_poza1 = htmlentities($image_url.$row['imgfile']);
			}
			elseif (trim($row['poza']) != '')
			{
				$url_poza1 = htmlentities($image_url.$row['poza']);
			}
			
			/* 
			 * Creeaza un array cu datele din fiecare tupla si initializeaza cu valori default campurile optionale 
			 * daca nu au fost aduse din baza de date sau nu gasesc variabilele cu numele corect
			 */
			$produs = array(
				// --> date obligatorii
				'CodProdusMercant'	=> $cod,
				'NumeMarca' 		=> $marca,
				'NumeProdus'		=> $nume_produs,
				'URL'				=> $url_produs,
				'NumeCategorie'		=> $nume_categorie,
				'PretLei'			=> $pret_lei,
				'InStoc'			=> $inStoc,
				// <-- 
				// --> date optionale
				'Garantia'			=> (isset($garantia)) 			? $garantia 		: '',
				'DescriereScurta'	=> (isset($descriere_scurta)) 	? $descriere_scurta : '',
				'Descriere'			=> (isset($descriere)) 			? $descriere		: '',
				'URL_poza1'			=> (isset($url_poza1)) 			? $url_poza1 		: '',
				'URL_poza2'			=> (isset($url_poza2)) 			? $url_poza2 		: '',
				'URL_poza3'			=> (isset($url_poza3)) 			? $url_poza3 		: '',
				'CategoriiProdus'	=> (isset($categorie)) 			? $categorie 		: '',
				'CodProducator'		=> (isset($codProducator)) 		? $codProducator 	: '',
				'MPN'				=> (isset($mpn)) 				? $mpn 				: '',
				'Greutate'			=> (isset($greutate)) 			? $greutate 		: '',
				'TipStoc'			=> (isset($infoStoc)) 			? $infoStoc 		: '',
				'Activ'				=> (isset($activ)) 				? $activ 			: 1
				// <--
			);
			
			$nodProdus = "\t<produs id=\"$i\">\n";		// pentru fiecare tupla se creeaza cate un nod de produs
			
			foreach ($produs as $key => $valoare)						// parcurge arrayul produs
			{
				if ($valoare != '' and $valoare != -1)					// daca valorile nu sunt cele default
				{
					$nodProdus .= "\t\t<$key>$valoare</$key>\n";		// pentru fiecare camp din array se creeaza noduri copii ai nodului produs
				}
			}

			$nodProdus .= "\t</produs>\n";		// pentru fiecare tupla se inchide nodul de produs
			
			echo $nodProdus;					// afisez nodul construit
			flush();							// fortez afisare

			$i++;								// incrementez counter
		}
		
		$xmlFoot = "</produse>";		// definesc footerul documentului XML
		echo $xmlFoot;					// afisez footerul
		flush();						// fortez afisare
		
		/**
		 * END Sectiune generare si afisare XML
		 */
	}
	/**
	 * Descriere: asigura conectarea la baza de date
	 * 
	 * @author Vlad Pop
	 * @version Wed Feb 13 10:23:36 EET 2008
	 */
	function connect(&$sqlAcces)
	{
		if(
				isset($sqlAcces) 
				and is_array($sqlAcces)
				and key_exists('databaseType', $sqlAcces)
				and key_exists('username', $sqlAcces)
				and key_exists('password', $sqlAcces)
				and key_exists('host', $sqlAcces)
				and key_exists('database', $sqlAcces)
			)
		{
			switch ($sqlAcces['databaseType'])
			{
				case 'mssql':
					$this->dbType		= $sqlAcces['databaseType'];
					
					$this->conexiune = mssql_connect ($sqlAcces['host'], $sqlAcces['username'], $sqlAcces['password']);
					if (!$this->conexiune)
						die('Nu ma pot conecta la serverul SQL. Verificati parametrii de conectare!');
						
					if (!mssql_select_db ($sqlAcces['database'], $this->conexiune)) 
						die('Nu pot selecta baza de date: '.$sqlAcces['database'].'. Verificati daca denumirea este corecta!');					
					break;				
				case 'mysql':
					$this->dbType		= $sqlAcces['databaseType'];
					
					$this->conexiune = mysql_connect ($sqlAcces['host'], $sqlAcces['username'], $sqlAcces['password']);
					if (!$this->conexiune)
						die('Nu ma pot conecta la serverul SQL. Verificati parametrii de conectare!'.mysql_error());
						
					if (!mysql_select_db ($sqlAcces['database'], $this->conexiune)) 
						die('Nu pot selecta baza de date: '.$sqlAcces['database'].'. Verificati daca denumirea este corecta!'.mysql_error());
					break;
			}			
		}
		else 
		{
			die('Nu ma pot conecta la serverul SQL. Verificati parametrii de conectare!'.mysql_error());
		}
	}
	/**
	 * Descriere: 
	 * 
	 * @author Vlad Pop
	 * @version Wed Feb 13 13:15:31 EET 2008
	 */
	function query($query)
	{
		if (trim($query) != '' and !is_null($this->conexiune) and !is_null($this->dbType)) 
		{
			switch ($this->dbType)
			{
				case 'mssql':
					$result = mssql_query($query, $this->conexiune);
					break;				
				case 'mysql':
					$result = mysql_query($query, $this->conexiune);
					break;
			}
			return $result;
		}
		return false;
	}
	/**
	 * Descriere: aduce linie cu linie o tupla din DB
	 * 
	 * @author Vlad Pop
	 * @version Wed Feb 13 13:18:40 EET 2008
	 */
	function fetch_assoc($result=null)
	{
		if (!is_null($result) and !is_null($this->dbType)) 
		{
			switch ($this->dbType)
			{
				case 'mssql':
					return mssql_fetch_assoc($result);
					break;				
				case 'mysql':
					return mysql_fetch_assoc($result);
					break;
			}
		}
		return false;
	}
	
	/**
	 * Realizeaza recursiv un arbore din sirul de categorii
	 *
	 * @param array $ARR
	 * @param array $TREE
	 * @param int $fk_cat
	 * @param int $lvl
	 * @param string $parent_field
	 * @param string $cat_key
	 * @return array
	 */
	function make_tree($ARR, $TREE=array(), $fk_cat = 0, $lvl = 0, $parent_field = "parent_id", $cat_key = "category_id")
	{
		$lvl ++;
		if (sizeof($ARR) > 0 && is_array($ARR)) {
			foreach ($ARR as $key => $val){
				if($val[$parent_field] == $fk_cat){
					$val['root_level'] = $lvl;
					$prev_cat_string = isset($TREE[$val[$parent_field]]['cat_string']) ? $TREE[$val[$parent_field]]['cat_string'] : '';
					$val['cat_string'] = $prev_cat_string . " > " . $val['name'];
					if (substr($val['cat_string'], 0, 2) == ' >')
					{
						$val['cat_string'] = substr($val['cat_string'], 3);
					}
					$TREE[$key] = $val;
					$TREE = $this->make_tree($ARR, $TREE, $val[$cat_key], $lvl, $parent_field, $cat_key);
				}
			}
		}
		return $TREE;
	}
}


/**
 * MAIN
 * 
 * Generare output in format XML cu lista de produse
 */
$exporter = new Export($sqlAcces);
$exporter->generateTextXMLOutput($site_url, $image_url);

?>